# (ARt1nesE ^+slime 7raN5lA7OR ++💯-

To-_XO TR4NSlaT3 !++~ 4-slatt+_ me554g3, *XO 2Un ^*💔 mA1n.P`/ _!!_ aND-+forever+ PaSS _woah_ 5TR1n9-+_100 as _!!\*-4n ok+^ 4RgumEn7 !ok🦋!

```python
python 'hello world'
# hEL|o--*woah*--wOr|)   ok+^---
```

## 7акЖ3 ^Lit*+ ПоЗbОлЯЕт-*xo!_ n3pевОДИт +vampire+ рycсКnй 💫!+ н4 +💀_ yaЗyk +👹+ кАР7n-+ok
